:github_url:

.. _cli:

CLI
===

The command line interface (CLI) is one of two modes of usage, next to *scherbelberg*'s :ref:`API <api>`.

.. click:: scherbelberg._cli:cli
  :prog: scherbelberg
  :show-nested:
